@@ -107,11 +107,15 @@ namespace MODEL_PARAMS
     return charVelScalar;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createCohesionEnergyDensity(PropertyRegistry & registry, const char * caller, bool sanity_checks)
   {
     return createPerTypePairProperty(registry, COHESION_ENERGY_DENSITY, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   VectorProperty * createYoungsModulus(PropertyRegistry & registry, const char * caller, bool sanity_checks)
   {
     LAMMPS * lmp = registry.getLAMMPS();
@@ -139,6 +143,8 @@ namespace MODEL_PARAMS
     return vec;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   VectorProperty * createPoissonsRatio(PropertyRegistry & registry, const char * caller, bool sanity_checks)
   {
     LAMMPS * lmp = registry.getLAMMPS();
@@ -164,6 +170,8 @@ namespace MODEL_PARAMS
     return vec;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty * createYeff(PropertyRegistry & registry, const char * caller, bool)
   {
     const int max_type = registry.max_type();
@@ -192,6 +200,8 @@ namespace MODEL_PARAMS
     return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty * createGeff(PropertyRegistry & registry, const char * caller, bool)
   {
     const int max_type = registry.max_type();
@@ -221,8 +231,10 @@ namespace MODEL_PARAMS
     return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty * createCoeffRest(PropertyRegistry & registry, const char * caller, bool sanity_checks)
-   {
+  {
      LAMMPS * lmp = registry.getLAMMPS();
      const int max_type = registry.max_type();
 
@@ -247,7 +259,9 @@ namespace MODEL_PARAMS
      }
 
      return matrix;
-   }
+  }
+
+  /* ---------------------------------------------------------------------- */
 
   MatrixProperty * createCoeffRestLog(PropertyRegistry & registry, const char * caller, bool)
   {
@@ -270,6 +284,8 @@ namespace MODEL_PARAMS
     return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty * createBetaEff(PropertyRegistry & registry, const char * caller, bool)
   {
     const int max_type = registry.max_type();
@@ -291,21 +307,29 @@ namespace MODEL_PARAMS
     return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createCoeffFrict(PropertyRegistry & registry, const char * caller, bool)
   {
     return createPerTypePairProperty(registry, COEFFICIENT_FRICTION, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createCoeffRollFrict(PropertyRegistry & registry, const char * caller, bool)
   {
     return createPerTypePairProperty(registry, COEFFICIENT_ROLL_FRICTION, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createCoeffRollVisc(PropertyRegistry & registry, const char * caller, bool)
   {
     return createPerTypePairProperty(registry, COEFFICIENT_ROLL_VISCOUS_DAMPING, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty * createCoeffMu(PropertyRegistry & registry, const char * caller, bool sanity_checks)
   {
     LAMMPS * lmp = registry.getLAMMPS();
@@ -333,6 +357,8 @@ namespace MODEL_PARAMS
     return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty * createCoeffRestMax(PropertyRegistry & registry, const char * caller, bool sanity_checks)
   {
    LAMMPS * lmp = registry.getLAMMPS();
@@ -360,6 +386,8 @@ namespace MODEL_PARAMS
    return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty * createCoeffStc(PropertyRegistry & registry, const char * caller, bool sanity_checks)
   {
    LAMMPS * lmp = registry.getLAMMPS();
@@ -387,26 +415,36 @@ namespace MODEL_PARAMS
    return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   ScalarProperty* createLiquidVolume(PropertyRegistry & registry, const char * caller, bool)
   {
     return createScalarProperty(registry, LIQUID_VOLUME, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   ScalarProperty* createSurfaceTension(PropertyRegistry & registry, const char * caller, bool)
   {
     return createScalarProperty(registry, SURFACE_TENSION, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   ScalarProperty* createSwitchModel(PropertyRegistry & registry, const char * caller, bool)
   {
     return createScalarProperty(registry, SWITCH_MODEL, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   ScalarProperty* createHistoryIndex(PropertyRegistry & registry, const char * caller, bool)
   {
     return createScalarProperty(registry, HISTORY_INDEX, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   VectorProperty * createContactAngle(PropertyRegistry & registry, const char * caller, bool sanity_checks)
   {
     LAMMPS * lmp = registry.getLAMMPS();
@@ -422,16 +460,18 @@ namespace MODEL_PARAMS
       // error checks on v
       if(sanity_checks)
       {
-        if(vi < 0. || vi > 180)
+        if(vi < 0. || vi > 180.)
           lmp->error->all(FLERR,"0 <= contactAngle <= 180° required");
       }
 
-      vec->data[i] = vi;
+      vec->data[i] = vi * M_PI / 180.; // from grad to rad
     }
 
     return vec;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createKn(PropertyRegistry & registry, const char * caller, bool)
   {
     LAMMPS * lmp = registry.getLAMMPS();
@@ -453,11 +493,15 @@ namespace MODEL_PARAMS
     return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createKt(PropertyRegistry & registry, const char * caller, bool)
   {
     return createPerTypePairProperty(registry, "kt", caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createGamman(PropertyRegistry & registry, const char * caller, bool)
   {
     LAMMPS * lmp = registry.getLAMMPS();
@@ -479,11 +523,15 @@ namespace MODEL_PARAMS
     return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createGammat(PropertyRegistry & registry, const char * caller, bool)
   {
     return createPerTypePairProperty(registry, "gammat", caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createGammanAbs(PropertyRegistry & registry, const char * caller, bool)
   {
     LAMMPS * lmp = registry.getLAMMPS();
@@ -505,23 +553,33 @@ namespace MODEL_PARAMS
     return matrix;
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createGammatAbs(PropertyRegistry & registry, const char * caller, bool)
   {
     return createPerTypePairProperty(registry, "gammat_abs", caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createCoeffMaxElasticStiffness(PropertyRegistry & registry, const char * caller, bool)
   {
     return createPerTypePairProperty(registry, COEFFICIENT_MAX_ELASTIC_STIFFNESS, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createCoeffAdhesionStiffness(PropertyRegistry & registry, const char * caller, bool)
   {
     return createPerTypePairProperty(registry, COEFFICIENT_ADHESION_STIFFNESS, caller);
   }
 
+  /* ---------------------------------------------------------------------- */
+
   MatrixProperty* createCoeffPlasticityDepth(PropertyRegistry & registry, const char * caller, bool)
   {
     return createPerTypePairProperty(registry, COEFFICIENT_PLASTICITY_DEPTH, caller);
   }
+
+  /* ---------------------------------------------------------------------- */
 }
