@@ -51,6 +51,8 @@
 #include "error.h"
 #include "neigh_multi_level_grid.h" 
 #include "math_extra_liggghts.h"    
+#include "fix_contact_history.h"
+#include <assert.h>
 
 using namespace LAMMPS_NS;
 
@@ -584,11 +586,13 @@ void Neighbor::init()
 
       if (requests[i]->granhistory) {
         lists[i-1]->listgranhistory = lists[i];
-        for (int ifix = 0; ifix < modify->nfix; ifix++)
-          if (strcmp(modify->fix[ifix]->style,"contacthistory") == 0)  
-            lists[i-1]->fix_history = (FixContactHistory *) modify->fix[ifix]; 
-           processed = 1;
-
+        for (int ifix = 0; ifix < modify->nfix; ifix++){
+          if (strcmp(modify->fix[ifix]->style,"contacthistory") == 0) {  
+            lists[i-1]->fix_history = dynamic_cast<FixContactHistory*>(modify->fix[ifix]); 
+            assert(lists[i-1]->fix_history != NULL);
+          }
+        }
+        processed = 1;
       } else if (requests[i]->respaouter) {
         if (requests[i-1]->respainner) {
           lists[i]->respamiddle = 0;
@@ -757,6 +761,29 @@ void Neighbor::init()
 #ifdef NEIGH_LIST_DEBUG
     print_lists_of_lists();
 #endif
+  } else {
+    for (i = 0; i < nlist; i++) {
+      if (requests[i]->pair) {
+        Pair *pair = (Pair *) requests[i]->requestor;
+        pair->init_list(requests[i]->id,lists[i]);
+      } else if (requests[i]->fix) {
+        Fix *fix = (Fix *) requests[i]->requestor;
+        fix->init_list(requests[i]->id,lists[i]);
+      } else if (requests[i]->compute) {
+        Compute *compute = (Compute *) requests[i]->requestor;
+        compute->init_list(requests[i]->id,lists[i]);
+      }
+
+      // update contacthistory pointer
+      if (requests[i]->granhistory) {
+        for (int ifix = 0; ifix < modify->nfix; ifix++) {
+          if (strcmp(modify->fix[ifix]->style,"contacthistory") == 0) {  
+            lists[i-1]->fix_history = dynamic_cast<FixContactHistory*>(modify->fix[ifix]); 
+            assert(lists[i-1]->fix_history != NULL);
+          }
+        }
+      }
+    }
   }
 
   // delete old requests
